@@ -1,7 +1,7 @@
 # encoding: utf-8
 # title: Spec buttons for apps
 # description: Adds configurable mini toolbar buttons
-# version: 0.8.2
+# version: 0.8.4
 # depends: streamtuner2 >= 2.2.0
 # type: feature
 # category: ui
@@ -24,6 +24,13 @@
 #
 # Icons can be gtk-xyz icon names or /usr/share/icon/* PNG files.
 # Each command may use streamtuner2 placeholders like %g or %url and $title.
+#
+# Internal functions can be bound now as well, for example:
+#
+#  find    search.menu_search(1)
+#
+#  disk    exportcat.savewindow(1)
+#
 
 
 import os.path
@@ -106,7 +113,7 @@ class specbuttons(object):
             return None
         path, err = f.communicate()
         if not err:
-            return path.split("\n")[0]
+            return path.decode("utf-8").split("\n")[0]
 
     # Update paths when saving config dialog
     def update_paths(self):
@@ -128,8 +135,18 @@ class specbuttons(object):
 
     # Button callback, allow for %url/%title placeholders
     def action(self, cmd):
+        # code hooks (`search.menu_search(0)`)
+        internal = re.match("^(\w+)\.(\w+)\((.*)\)$", cmd)
+        if internal:
+            feature, func, args = internal.groups()
+            if self.parent.__getattr__(feature):
+                func = getattr(self.parent.__getattr__(feature), func)
+                if func:
+                    return func(*(args.split()))
+        # external commands
         if re.search("[%$]", cmd):
             row = self.parent.channel().row()
-            cmd = action.run_fmt_url(cmd, row=row, add_default=False, cmd=cmd)
-        action.run(cmd)
+            action.run_fmt_url(row=row, add_default=False, cmd=cmd)
+        else:
+            action.run(cmd)
 
