@@ -1,7 +1,7 @@
 # encoding: utf-8
 # title: Version/update check on startup
 # description: Checks fossil repository for newer version
-# version: 1.0
+# version: 1.1
 # depends: streamtuner2 >= 2.2.0
 # priority: default
 # type: feature
@@ -9,7 +9,7 @@
 #
 # Probes http://fossil.include-once.org/streamtuner2/cat/releases.json
 # for newer version. Activates only on ~20% of startups, only adds a statusbar
-# notification after 10 seconds, no nag screen.
+# notification after 5 seconds, no nag screen.
 
 
 import json
@@ -17,17 +17,16 @@ import ahttp
 import random
 import threading
 from config import plugin_meta
+from channels import FeaturePlugin
 
 # Update notification
-class version_check(object):
-    module = 'version_check'
-    parent = None
+class version_check(FeaturePlugin):
 
     # Hook timer
-    def __init__(self, parent):
-        if random.randint(0,5) == 1:
-            threading.Timer(10, self.check).start()
-            self.parent = parent
+    def init2(self, parent):
+        if random.randint(0,5):
+            return
+        threading.Timer(5, self.check).start()
 
     # Request release.json, notify in status bar
     def check(self, *x, **y):
@@ -38,6 +37,6 @@ class version_check(object):
             m = plugin_meta(module="st2", extra_base=["config"])
             ver = m["version"]
             if ver < max:
-                self.parent.status(text="A newer streamtuner2 version (→%s) is available." % str(ver), timeout=7)
+                self.status(text="A newer streamtuner2 version (→%s) is available." % str(ver), timeout=7, icon="gtk-dialog-info")
         except:
             None
\ No newline at end of file
