@@ -13,7 +13,7 @@
 #    { arg: -x,     type: boolean,  name: exit,      hidden: 1 }
 #    { arg: -V,     type: boolean,  name: version,   description: Print version.  }
 #    { arg: -w,     type: boolean,  name: pydoc,     hiden: 1  }
-# version: 2.7
+# version: 2.8
 # priority: core
 # depends: pluginconf >= 0.1, os, json, re, zlib, pkgutil
 #
@@ -41,6 +41,7 @@
 from __future__ import print_function
 import os, glob
 import sys
+from traceback import format_exc
 import json
 import gzip
 import platform
@@ -101,6 +102,10 @@ class ConfigDict(dict):
         else:
             self.save("settings")
             self.firstrun = 1
+        try:
+            self.version = plugin_meta(frame=3).get("version", "2.2")
+        except Exception as e:
+            self.version = "2.2"
 
         # temporary files
         if not os.path.exists(self.tmp):
@@ -139,7 +144,7 @@ class ConfigDict(dict):
         }
         self.tmp = os.environ.get("TEMP", "/tmp") + "/streamtuner2"
         self.nothreads = 0
-        self.max_streams = "500"
+        self.max_streams = 500
         self.internetradio_max_pages = 5
         self.show_bookmarks = 1
         self.show_favicons = 1
@@ -156,6 +161,7 @@ class ConfigDict(dict):
         self.pyquery = 1
         self.debug = 0
         self.status_color = "#ffeecc"
+        self.searchbtn = 0
 
     # update old setting names
     def migrate(self):
@@ -205,13 +211,34 @@ class ConfigDict(dict):
     def xdg(self, path="/streamtuner2"):
         home = os.environ.get("HOME", self.tmp)
         config = os.environ.get("XDG_CONFIG_HOME", os.environ.get("APPDATA", home+"/.config"))
+        datadir = os.environ.get("XDG_CACHE_HOME", os.environ.get("APPDATA", home+"/.cache"))
         
         # storage dir
         self.dir = config + path
+        self.datadir = datadir + path
         
         # create if necessary
         if (not os.path.exists(self.dir)):
             os.makedirs(self.dir)
+        if (not os.path.exists(self.datadir)):
+            os.makedirs(self.datadir)
+
+        # symlink subdirs from .config to .cache
+        self.xdg_move(self.dir, self.datadir, ["cache", "icons", "themes"])
+
+    # move/symlink cache files/dirs into datadir
+    def xdg_move(self, config_dir, cache_dir, folders):
+        if self.windows:
+            return
+        for sub in folders:
+            source, target = (dir+"/"+sub for dir in [config_dir, cache_dir])
+            if not os.path.exists(target):
+                if os.path.exists(source): # move .config/* to .cache/*
+                    os.rename(source, target)
+                else:
+                    os.makedirs(target)    # create .cache/*
+            if os.path.exists(target) and not os.path.exists(source):
+                os.symlink(target, source) # symlink .config → .cache
        
 
     # store some configuration list/dict into a file                
@@ -222,15 +249,16 @@ class ConfigDict(dict):
             if "args" in data:
                 data.pop("args")
             nice = 1
+        # target filename
+        file = self.dir + "/" + name
         # check for subdir
         if (name.find("/") > 0):
             subdir = name[0:name.find("/")]
-            subdir = self.dir + "/" + subdir
+            subdir = self.datadir + "/" + subdir
             if (not os.path.exists(subdir)):
                 os.mkdir(subdir)
                 open(subdir+"/.nobackup", "w").close()
-        # target filename
-        file = self.dir + "/" + name
+            file = self.datadir + "/" + name
         # encode as JSON
         try:
             data = json.dumps(data, indent=(4 if nice else None), sort_keys=True)
@@ -254,7 +282,10 @@ class ConfigDict(dict):
     # retrieve data from config file            
     def load(self, name):
         name = name + ".json"
-        file = self.dir + "/" + name
+        if (name.find("/") > 0):
+            file = self.datadir + "/" + name
+        else:
+            file = self.dir + "/" + name
         try:
             # .gz or normal file
             if os.path.exists(file + ".gz"):
@@ -348,7 +379,12 @@ class log_printer(object):
         else:
             method = r"[{}[{}][0m".format(self.colors.get(method.split("_")[0], "47m"), method)
         # output
-        print(method + " " + " ".join([str(a) for a in args]), file=sys.stderr)
+        print(
+            method + " " + " " . join(
+                format_exc() if isinstance(a, Exception) else str(a) for a in args
+            ),
+            file=sys.stderr
+        )
 
     # Colors
     colors = {
