@@ -2,7 +2,7 @@
 # api: streamtuner2
 # title: Recording options
 # description: Allows to set streamripper/fIcy options before recording
-# version: 0.9
+# version: 1.0
 # depends: streamtuner2 > 2.2.0
 # conflicts: continuous_record
 # priority: optional
@@ -21,15 +21,14 @@
 # less pretty than a custom dialog, but allows to set options for different
 # download/recording tools: streamripper, fPls, youtube-dl, wget.
 #
+# The presented parameter dialog depends on which tool is configured in the
+# Apps/Recording table to which audio type. (If you want fpls options, you
+# have to have fpls/ficy configured beforehand.)
+#
 # Note that predefining -flags in the Apps/Recording config table might
 # conflict with per-stream options. In particular avoid a -d directory
 # default for streamripper; and use this plugins´ option instead.
 #
-# ToDo:
-#  → override main.record() instead of action.record
-#  → eventually strip defaults such as `-d ../dir` from conf.record;
-#    using action append= param now, thus no rewriting of assoc dict
-#
 
 
 import re
@@ -43,6 +42,12 @@ from compat2and3 import *
 
 
 # hook record button / menu / action
+#
+# ToDo:
+#  → override main.record() instead of action.record
+#  → eventually strip defaults such as `-d ../dir` from conf.record;
+#    using action append= param now, thus no rewriting of assoc dict
+#
 class recordflags (FeaturePlugin):
 
     # settings
@@ -50,6 +55,8 @@ class recordflags (FeaturePlugin):
     widgets = {}
     
     # available options per recording tool
+    # · each dict here is basically a plugin meta data block,
+    # · with config=[] being applied by configwin.save/load/add_widgets
     flag_meta = {
         "streamripper": {
             "title": "streamripper",
@@ -168,7 +175,7 @@ class recordflags (FeaturePlugin):
                 # meta
                 { "name": "v", "arg": "-v", "type": "bool", "description": "<b>-v</b> Verbose mode", "value": False, "category": "meta" },
                 { "name": "d", "arg": "-d", "type": "bool", "description": "<b>-d</b> Debug mode", "value": False, "category": "meta" },
-                { "name": "enc", "arg": "--local-encoding", "type": "select", "select": "UTF-8|ISO-8859-1|ISO-8859-15", "description": "<b>--local-encoding</b>", "value": False, "category": "meta" },
+                { "name": "enc", "arg": "--local-encoding", "type": "select", "select": "UTF-8|ISO-8859-1|ISO-8859-15", "description": "<b>--local-encoding</b>", "value": "", "category": "meta" },
                 { "name": "e", "arg": "-e", "type": "str",  "description": "<b>-e</b> wgetrc-command", "value": "", "category": "meta" },
                 # net
                 { "name": "noch", "arg": "--no-cache", "type": "bool", "description": "<b>-S</b> No cached files", "value": False, "category": "net" },
@@ -205,9 +212,6 @@ class recordflags (FeaturePlugin):
         parent.recordoptions_eventbox.modify_bg(gtk.STATE_NORMAL, gtk.gdk.Color(0x44, 0x22, 0x11))
 
         # shortcuts
-        self.add_plg = parent.configwin.add_plg           # create _cfg widgets
-        self.load_config = parent.configwin.load_config   # populate _cfg widgets
-        self.save_config = parent.configwin.save_config   # save from _cfg widgets
         self.cfg_vbox = { 
             "basic": self.parent.recordoptions_cfg,
             "meta": self.parent.recordoptions_cfg_extra,
@@ -294,11 +298,17 @@ class recordflags (FeaturePlugin):
     # populate config widgets, seth defaults/current settings
     def load_config_widgets(self, row, group="streamripper", p=None):
         # clean up previous
-        [vbox.remove(w) for vbox in self.cfg_vbox.values() for w in vbox.get_children()]
+        for vbox in self.cfg_vbox.values():
+            for w in vbox.get_children():
+                vbox.remove(w)
         # add plugins
-        self.add_plg(group, self.flag_meta[group], self.pack_option, self.cfg_widget_pfx)
+        self.parent.configwin.add_plg(
+            group, self.flag_meta[group], self.pack_option, self.cfg_widget_pfx
+        )
         # set values
-        self.load_config(self.configdict_from_args(row), self.cfg_widget_pfx, widgets=self.widgets)
+        self.parent.configwin.load_config(
+            self.configdict_from_args(row), self.cfg_widget_pfx, widgets=self.widgets
+        )
 
     # Put config widgets into recordoptions_cfg_*** vbox
     def pack_option(self, id=None, w=None, label=None, color=None, image=None, align=5, opt={}):
@@ -309,8 +319,12 @@ class recordflags (FeaturePlugin):
         
     # return "--args str" for current config widget states
     def args_from_configwin(self):
-        cfg = { name: None for name in self.namemap.keys() }
-        self.save_config(cfg, self.cfg_widget_pfx, widgets=self.widgets)
+        cfg = {
+             name: None  for  name in self.namemap.keys()
+        }
+        self.parent.configwin.save_config(
+            cfg, self.cfg_widget_pfx, widgets=self.widgets
+        )
         #log.DATA(cfg)
         return self.args_from_configdict(cfg)
 
@@ -348,3 +362,4 @@ class recordflags (FeaturePlugin):
             if isinstance(val, (str, unicode)): # type == "bool" check here(...)
                 s = s + " " + val
         return s
+
