@@ -1,12 +1,16 @@
-# encoding: UTF-8
+# encoding: utf-8
 # api: python
-# type: handler
-# category: io
+# type: extract
+# category: config
 # title: Plugin configuration
 # description: Read meta data, pyz/package contents, module locating
-# version: 0.6.8
+# version: 0.7.5
+# state: stable
+# classifiers: documentation
+# license: PD
 # priority: core
-# docs: http://fossil.include-once.org/streamtuner2/wiki/plugin+meta+data
+# docs: https://fossil.include-once.org/pluginspec/
+# url: http://fossil.include-once.org/streamtuner2/wiki/plugin+meta+data
 # config: -
 #
 # Provides plugin lookup and meta data extraction utility functions.
@@ -82,11 +86,23 @@ import os
 import re
 import pkgutil
 import inspect
-from compat2and3 import find_executable
 try:
-    from compat2and3 import gzip_decode
+    from distutils.spawn import find_executable
 except:
+    try: 
+        from compat2and3 import find_executable
+    except:
+        def find_executable(str):
+            pass
+try:
     from gzip import decompress as gzip_decode  # Py3 only
+except:
+    try:
+        from compat2and3 import gzip_decode   # st2 stub
+    except:
+        def gzip_decode(bytes):
+            import zlib
+            return zlib.decompress(bytes, 16 + zlib.MAX_WBITS)    # not fully compatible
 import zipfile
 import argparse
 
@@ -101,11 +117,11 @@ __all__ = [
 log_ERR = lambda *x: None
 
 # File lookup relation for get_data(), should name a top-level package.
-module_base = "config"
+module_base = "config"         # equivalent PluginBase(package=…)
 
 # Package/module names for module_list() and plugin_meta() lookups.
 # All associated paths will be scanned for module/plugin basenames.
-plugin_base = ["channels"]
+plugin_base = ["channels"]     # equivalent to `searchpath` in PluginBase
 
 
 # Resource retrieval
@@ -226,7 +242,7 @@ def plugin_meta_extract(src="", fn=None, literal=False):
 
     # Defaults
     meta = {
-        "id": os.path.splitext(os.path.basename(fn or "")),
+        "id": os.path.splitext(os.path.basename(fn or ""))[0],
         "fn": fn,
         "api": "python",
         "type": "module",
@@ -255,7 +271,7 @@ def plugin_meta_extract(src="", fn=None, literal=False):
 
     # Turn key:value lines into dictionary
     for field in rx.keyval.findall(src):
-        meta[field[0]] = field[1].strip()
+        meta[field[0].replace("-", "_")] = field[1].strip()
     meta["config"] = plugin_meta_config(meta.get("config") or "")
 
     return meta
@@ -284,9 +300,27 @@ def plugin_meta_config(str):
         }
         for field in rx.options.findall(entry):
             opt[field[0]] = (field[1] or field[2] or field[3] or "").strip()
+        # normalize type
+        opt["type"] = config_opt_type_map.get(opt["type"], opt["type"] or "str")
+        # preparse select:
+        if opt.get("select"):
+            opt["select"] = config_opt_parse_select(opt.get("select", ""))
         config.append(opt)
     return config
 
+# split up `select: 1=on|2=more|3=title` or `select: foo|bar|lists`
+def config_opt_parse_select(s):
+    if re.search("([=:])", s):
+        return dict(rx.select_dict.findall(s))
+    else:
+        return dict([(v, v) for v in rx.select_list.findall(s)])
+
+# normalize type:names to `str`, `text`, `bool`, `int`, `select`, `dict`
+config_opt_type_map = dict(
+    longstr="text", string="str", boolean="bool", checkbox="bool", integer="int", number="int",
+    choice="select", options="select", table="dict", array="dict"
+)
+
 
 # Comment extraction regexps
 # ‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾
@@ -296,7 +330,7 @@ def plugin_meta_config(str):
 #
 class rx:
     comment = re.compile(r"""(^ {0,4}#.*\n)+""", re.M)
-    hash = re.compile(r"""(^ {0,4}# *\r*)""", re.M)
+    hash = re.compile(r"""(^ {0,4}# {0,3}\r*)""", re.M)
     keyval = re.compile(r"""
         ^([\w-]+):(.*$(?:\n(?![\w-]+:).+$)*)      # plain key:value lines
     """, re.M | re.X)
@@ -311,6 +345,9 @@ class rx:
        |     ([^,]*)                           #  or unquoted literals
      )
     """, re.X)
+    select_dict = re.compile(r"(\w+)\s*[=:>]+\s*([^=,|:]+)")
+    select_list = re.compile(r"\s*([^,|;]+)\s*")
+
 
 
 # ArgumentParser options conversion
@@ -347,13 +384,13 @@ def argparse_map(opt):
         return {}
 
     # Extract --flag names
-    args = opt["arg"].split() + re.findall("-+\w+", opt["name"])
+    args = opt["arg"].split() + re.findall(r"-+\w+", opt["name"])
 
     # Prepare mapping options
-    typing = re.findall("bool|str|\[\]|const|false|true", opt["type"])
-    naming = re.findall("\[\]", opt["name"])
-    name = re.findall("(?<!-)\\b\\w+", opt["name"])
-    nargs = re.findall("\\b\d+\\b|[\?\*\+]", opt["type"]) or [None]
+    typing = re.findall(r"bool|str|\[\]|const|false|true", opt["type"])
+    naming = re.findall(r"\[\]", opt["name"])
+    name = re.findall(r"(?<!-)\b\w+", opt["name"])
+    nargs = re.findall(r"\b\d+\b|[\?\*\+]", opt["type"]) or [None]
     is_arr = "[]" in (naming + typing) and nargs == [None]
     is_bool = "bool" in typing
     false_b = "false" in typing or opt["value"] in ("0", "false")
@@ -417,34 +454,39 @@ class dependency(object):
         for name in core:
             self.have[name] = plugin_meta(module=name, extra_base=["config"])
         # aliases
-        for name, meta in self.have.items():
+        for name, meta in self.have.copy().items():
             if meta.get("alias"):
-                for alias in re.split("\s*[,;]\s*", meta["alias"]):
+                for alias in re.split(r"\s*[,;]\s*", meta["alias"]):
                     self.have[alias] = self.have[name]
 
     # basic plugin pre-screening (skip __init__, filter by api:,
     # exclude installed & same-version plugins)
-    def valid(self, newpl):
+    def valid(self, newpl, _log=lambda *x:0):
         id = newpl.get("$name", "__invalid")
         have_ver = self.have.get(id, {}).get("version", "0")
         if id.find("__") == 0:
+            _log("wrong id")
             pass
         elif newpl.get("api") not in ("python", "streamtuner2"):
+            _log("wrong api")
             pass
         elif set((newpl.get("status"), newpl.get("priority"))).intersection(set(("obsolete", "broken"))):
+            _log("wrong status")
             pass
         elif have_ver >= newpl.get("version", "0.0"):
+            _log("newer version already installed")
             pass
         else:
             return True
 
     # Verify depends: and breaks: against existing plugins/modules
-    def depends(self, plugin):
+    def depends(self, plugin, _log=lambda *x:0):
         r = True
         if plugin.get("depends"):
             r &= self.and_or(self.split(plugin["depends"]), self.have)
         if plugin.get("breaks"):
             r &= self.neither(self.split(plugin["breaks"]), self.have)
+        _log(r)
         return r
 
     # Split trivial "pkg | alt, mod >= 1, uikit < 4.0" string into nested list [[dep],[alt,alt],[dep]]
@@ -529,15 +571,15 @@ def add_plugin_defaults(conf_options, conf_plugins, meta={}, module=""):
             _name = opt.get("name")
             _type = opt.get("type")
             if _name not in conf_options:
-                # typemap "bool" and "int" here
-                if _type in ("bool", "boolean"):
+                # typemap
+                if _type == "bool":
                     val = _value.lower() in ("1", "true", "yes", "on")
-                elif _type in ("int", "integer", "numeric"):
+                elif _type == "int":
                     val = int(_value)
-                elif _type in ("array", "table", "list"):
-                    val = [ re.split("\s*[,;]\s*", s.strip()) for s in re.split("\s[|]\s*", _value) ]
-                elif _type in ("dict"):
-                    val = dict([ re.split("\s*(?:=>+|==*|-+>|:=+)\s*", s.strip()) for s in re.split("\s*[|;,]\s*", _value) ])
+                elif _type in ("table", "list"):
+                    val = [ re.split(r"\s*[,;]\s*", s.strip()) for s in re.split(r"\s*[|]\s*", _value) ]
+                elif _type == "dict":
+                    val = dict([ re.split(r"\s*(?:=>+|==*|-+>|:=+)\s*", s.strip(), 1) for s in re.split(r"\s*[|;,]\s*", _value) ])
                 else:
                     val = str(_value)
                 conf_options[_name] = val
