@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-# encoding: UTF-8
+# encoding: utf-8
 # api: python
 # type: application
 # title: streamtuner2
 # description: Directory browser for internet radio, audio and video streams
-# version: 2.2.1
+# version: 2.2.2
 # state: stable
 # author: Mario Salzer <mario@include-once.org>
 # license: Public Domain
@@ -13,7 +13,8 @@
 #   { type: env, name: HTTP_PROXY, description: proxy for HTTP access }
 #   { type: env, name: XDG_CONFIG_HOME, description: relocates user .config subdirectory }
 # category: sound
-# depends: pygtk | gi, threading, requests, pyquery, lxml
+# depends: python (>= 2.7) | python3 (>= 3.2), python:pygtk | python:gobject,
+#   python:requests (>= 1.1), python:pyquery, python:pillow, python:xdg
 # alias: streamtuner2, main
 # id: st2
 # pack: *.py, gtk3.xml.gz, bin, channels/__init__.py, bundle/*.py, CREDITS, help/index.page,
@@ -32,8 +33,8 @@
 # station lists.
 #
 # Primarily radio stations are displayed, some channels however
-# are music collections. Commercial and sign-up services are not
-# an objective.
+# are music collections or video platforms. Commercial and sign-up
+# services are not an objective.
 
 
 # standard modules
@@ -256,6 +257,7 @@ class StreamTunerTwo(gtk.Builder):
         # if first selected, load current category
         # (run in thread, to make it look speedy on first startup)
         self.thread(self.channel().first_show)
+        log.UI("channel_switch done.")
 
     # Invoked from the menu instead, uses module name instead of numeric tab id
     def channel_switch_by_name(self, name):
@@ -323,8 +325,8 @@ class StreamTunerTwo(gtk.Builder):
         pass
 
     # Add current selection to bookmark store
-    def bookmark(self, widget):
-        self.bookmarks.add(self.row())
+    def bookmark(self, widget, target="favourite"):
+        self.bookmarks.add(self.row(), target)
         self.channel().row_icon(gtk.STOCK_ABOUT)
         # refresh bookmarks tab
         self.bookmarks.load(self.bookmarks.default)
