@@ -166,13 +166,14 @@ class uikit:
             }
             if gtk.gdk.Pixbuf in vartypes:
                 pix_entry = vartypes.index(gtk.gdk.Pixbuf) 
-            
+
+            normal_bg = uikit.get_bg_color(widget)
             # sort data into gtk liststore array
             for row in entries:
 
                 # preset some values if absent
                 row.setdefault("deleted", False)
-                row.setdefault("search_col", "#ffffff")
+                row.setdefault("search_col", normal_bg) #ffffff
                 row.setdefault("search_set", False)
 
                 # generate ordered list from dictionary, using rowmap association
@@ -209,6 +210,16 @@ class uikit:
         pass
 
 
+    # figure out standard background
+    @staticmethod
+    def get_bg_color(widget):
+        try:
+            # Gtk3 only
+            normal_bg = widget.get_style_context().get_background_color(gtk.StateType.NORMAL)
+            normal_bg = normal_bg.to_string()
+        except:
+            normal_bg = ""  # just live with the inevitable Warning
+        return normal_bg
 
 
     #-- treeview for categories
@@ -578,15 +589,25 @@ class uikit:
 
     # Attach textual menu entry and callback
     @staticmethod
-    def add_menu(menuwidget, label, action, insert=None):
+    def add_menu(menuwidget, label, action=None, stock=None, submenu=None, insert=None):
         for where in list(menuwidget):
-            m = gtk.MenuItem(label)
-            m.connect("activate", action)
-            m.show()
+            # plain or image menu item
+            if stock:
+                m = gtk.ImageMenuItem(stock)
+                m.set_label(label)
+            else:
+                m = gtk.MenuItem(label)
+            # callback or submenu
+            if action:
+                m.connect("activate", action)
+            elif submenu:
+                m.set_submenu(submenu)
+            # insert or append
             if insert:
                 where.insert(m, insert)
             else:
                 where.add(m)
+            m.show()
         
 
     # gtk.messagebox
@@ -694,9 +715,11 @@ class ComboBoxText(gtk.ComboBox):
         # collect entries
         self.ls = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
         self.set_model(self.ls)
-        if type(entries[0]) is not tuple:
-            entries = zip(entries, entries)
-        for key,value in entries:
+        if isinstance(entries, str):
+            entries = ComboBoxText.parse_options(entries)
+        if isinstance(entries, list):
+            entries = dict(zip(entries, entries))
+        for key,value in entries.items():
             self.ls.append([key, value])
         
     # activate dropdown of given value
